Ansys Common Tools
==================
|pyansys| |python| |pypi| |MIT| |GH-CI| |pre-commit|

.. |pyansys| image:: https://img.shields.io/badge/Py-Ansys-ffc107.svg?logo=data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAACQkWg2AAABDklEQVQ4jWNgoDfg5mD8vE7q/3bpVyskbW0sMRUwofHD7Dh5OBkZGBgW7/3W2tZpa2tLQEOyOzeEsfumlK2tbVpaGj4N6jIs1lpsDAwMJ278sveMY2BgCA0NFRISwqkhyQ1q/Nyd3zg4OBgYGNjZ2ePi4rB5loGBhZnhxTLJ/9ulv26Q4uVk1NXV/f///////69du4Zdg78lx//t0v+3S88rFISInD59GqIH2esIJ8G9O2/XVwhjzpw5EAam1xkkBJn/bJX+v1365hxxuCAfH9+3b9/+////48cPuNehNsS7cDEzMTAwMMzb+Q2u4dOnT2vWrMHu9ZtzxP9vl/69RVpCkBlZ3N7enoDXBwEAAA+YYitOilMVAAAAAElFTkSuQmCC
   :target: https://docs.pyansys.com/
   :alt: PyAnsys

.. |python| image:: https://img.shields.io/pypi/pyversions/ansys-tools-common?logo=pypi
   :target: https://pypi.org/project/ansys-tools-common/
   :alt: Python

.. |pypi| image:: https://img.shields.io/pypi/v/ansys-tools-common.svg?logo=python&logoColor=white
   :target: https://pypi.org/project/ansys-tools-common
   :alt: PyPI

.. |MIT| image:: https://img.shields.io/badge/License-MIT-yellow.svg
   :target: https://opensource.org/licenses/MIT
   :alt: MIT

.. |GH-CI| image:: https://github.com/ansys/ansys-tools-common/actions/workflows/cicd.yml/badge.svg
   :target: https://github.com/ansys/ansys-tools-common/actions/workflows/cicd.yml
   :alt: GH-CI

.. |pre-commit| image:: https://results.pre-commit.ci/badge/github/ansys/ansys-tools-common/main.svg
   :target: https://results.pre-commit.ci/latest/github/ansys/ansys-tools-common/main
   :alt: pre-commit.ci status

Overview
--------

Ansys Common Tools provides a set of tools for the PyAnsys ecosystem.


Documentation and issues
------------------------

Documentation for the latest stable release of Ansys Common Tools is hosted
at `Ansys Common Tools documentation <https://ansys.tools.docs.pyansys.com/version/stable/index.html>`_.

The documentation has these sections:

- `Getting started <https://ansys.tools.docs.pyansys.com/version/stable/getting_started/index.html>`_: Learn
  how to install Ansys Common Tools in user mode.
- `User guide <https://ansys.tools.docs.pyansys.com/version/stable/user_guide/index.html>`_: Understand key
  concepts for implementing the tools in your workflows.
- `API reference <https://ansys.tools.docs.pyansys.com/version/stable/api/index.html>`_: Understand how to
  use Python to interact programmatically with the tools.
- `Contribute <https://ansys.tools.docs.pyansys.com/version/stable/contributing.html>`_: Learn how to
  contribute to the Ansys Common Tools codebase or documentation.

In the upper right corner of the documentation's title bar, there is an option
for switching from viewing the documentation for the latest stable release
to viewing the documentation for the development version or previously
released versions.

On the Ansys Common Tools `Issues <https://github.com/ansys/ansys-tools-common/issues>`_
page, you can create issues to report bugs and request new features. On the `Ansys Common Tools Discussions <https://github.com/ansys/ansys-tools-common/discussions>`_ page
or the `Discussions <https://discuss.ansys.com/>`_ page on the Ansys Developer portal,
you can post questions, share ideas, and get community feedback.

If you have general questions about the PyAnsys ecosystem, email
`pyansys.core@ansys.com <pyansys.core@ansys.com>`_. If your
question is specific to Ansys Common Tools, ask your
question in an issue as described in the previous paragraph.

License
-------

Ansys Common Tools is licensed under the `MIT License <https://github.com/ansys/ansys-tools-common/blob/main/LICENSE>`_.

Ansys Common Tools makes no commercial claim over Ansys whatsoever.
